==> doxygen-1.5.7.src.tar.bz2: doxygen-1.5.7/src/doxygen_css.h <==
"body, table, div, p, dl {\n"
"	font-family: Lucida Grande, Verdana, Geneva, Arial, sans-serif;\n"
"	font-size: 12px;\n"
"}\n"
"\n"
"/* @group Heading Levels */\n"
"\n"
"h1 {\n"
"	text-align: center;\n"
"	font-size: 150%;\n"
"}\n"
"\n"
"h2 {\n"
"	font-size: 120%;\n"
"}\n"
"\n"
"h3 {\n"
"	font-size: 100%;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"caption {\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"div.qindex, div.navpath, div.navtab{\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	padding: 2px;\n"
"}\n"
"\n"
"div.qindex, div.navpath {\n"
"	width: 100%;\n"
"	line-height: 140%;\n"
"}\n"
"\n"
"div.navtab {\n"
"	margin-right: 15px;\n"
"}\n"
"\n"
"/* @group Link Styling */\n"
"\n"
"a {\n"
"	color: #153788;\n"
"	font-weight: normal;\n"
"	text-decoration: none;\n"
"}\n"
"\n"
".contents a:visited {\n"
"	color: #1b77c5;\n"
"}\n"
"\n"
"a:hover {\n"
"	text-decoration: underline;\n"
"}\n"
"\n"
"a.qindex {\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"a.qindexHL {\n"
"	font-weight: bold;\n"
"	background-color: #6666cc;\n"
"	color: #ffffff;\n"
"	border: 1px double #9295C2;\n"
"}\n"
"\n"
"a.el {\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"a.elRef {\n"
"}\n"
"\n"
"a.code {\n"
"}\n"
"\n"
"a.codeRef {\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"dl.el {\n"
"	margin-left: -1cm;\n"
"}\n"
"\n"
".fragment {\n"
"	font-family: monospace, fixed;\n"
"	font-size: 105%;\n"
"}\n"
"\n"
"pre.fragment {\n"
"	border: 1px solid #CCCCCC;\n"
"	background-color: #f5f5f5;\n"
"	padding: 4px 6px;\n"
"	margin: 4px 8px 4px 2px;\n"
"}\n"
"\n"
"div.ah {\n"
"	background-color: black;\n"
"	font-weight: bold;\n"
"	color: #ffffff;\n"
"	margin-bottom: 3px;\n"
"	margin-top: 3px\n"
"}\n"
"\n"
"div.groupHeader {\n"
"	margin-left: 16px;\n"
"	margin-top: 12px;\n"
"	margin-bottom: 6px;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"div.groupText {\n"
"	margin-left: 16px;\n"
"	font-style: italic;\n"
"}\n"
"\n"
"body {\n"
"	background: white;\n"
"	color: black;\n"
"	margin-right: 20px;\n"
"	margin-left: 20px;\n"
"}\n"
"\n"
"td.indexkey {\n"
"	background-color: #e8eef2;\n"
"	font-weight: bold;\n"
"	border: 1px solid #CCCCCC;\n"
"	margin: 2px 0px 2px 0;\n"
"	padding: 2px 10px;\n"
"}\n"
"\n"
"td.indexvalue {\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #CCCCCC;\n"
"	padding: 2px 10px;\n"
"	margin: 2px 0px;\n"
"}\n"
"\n"
"tr.memlist {\n"
"	background-color: #f0f0f0;\n"
"}\n"
"\n"
"p.formulaDsp {\n"
"	text-align: center;\n"
"}\n"
"\n"
"img.formulaDsp {\n"
"	\n"
"}\n"
"\n"
"img.formulaInl {\n"
"	vertical-align: middle;\n"
"}\n"
"\n"
"/* @group Code Colorization */\n"
"\n"
"span.keyword {\n"
"	color: #008000\n"
"}\n"
"\n"
"span.keywordtype {\n"
"	color: #604020\n"
"}\n"
"\n"
"span.keywordflow {\n"
"	color: #e08000\n"
"}\n"
"\n"
"span.comment {\n"
"	color: #800000\n"
"}\n"
"\n"
"span.preprocessor {\n"
"	color: #806020\n"
"}\n"
"\n"
"span.stringliteral {\n"
"	color: #002080\n"
"}\n"
"\n"
"span.charliteral {\n"
"	color: #008080\n"
"}\n"
"\n"
"span.vhdldigit { \n"
"	color: #ff00ff \n"
"}\n"
"\n"
"span.vhdlchar { \n"
"	color: #000000 \n"
"}\n"
"\n"
"span.vhdlkeyword { \n"
"	color: #700070 \n"
"}\n"
"\n"
"span.vhdllogic { \n"
"	color: #ff0000 \n"
"}\n"
"\n"
"/* @end */\n"
"\n"
".search {\n"
"	color: #003399;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"form.search {\n"
"	margin-bottom: 0px;\n"
"	margin-top: 0px;\n"
"}\n"
"\n"
"input.search {\n"
"	font-size: 75%;\n"
"	color: #000080;\n"
"	font-weight: normal;\n"
"	background-color: #e8eef2;\n"
"}\n"
"\n"
"td.tiny {\n"
"	font-size: 75%;\n"
"}\n"
"\n"
".dirtab {\n"
"	padding: 4px;\n"
"	border-collapse: collapse;\n"
"	border: 1px solid #84b0c7;\n"
"}\n"
"\n"
"th.dirtab {\n"
"	background: #e8eef2;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"hr {\n"
"	height: 0;\n"
"	border: none;\n"
"	border-top: 1px solid #666;\n"
"}\n"
"\n"
"/* @group Member Descriptions */\n"
"\n"
".mdescLeft, .mdescRight,\n"
".memItemLeft, .memItemRight,\n"
".memTemplItemLeft, .memTemplItemRight, .memTemplParams {\n"
"	background-color: #FAFAFA;\n"
"	border: none;\n"
"	margin: 4px;\n"
"	padding: 1px 0 0 8px;\n"
"}\n"
"\n"
".mdescLeft, .mdescRight {\n"
"	padding: 0px 8px 4px 8px;\n"
"	color: #555;\n"
"}\n"
"\n"
".memItemLeft, .memItemRight, .memTemplParams {\n"
"	border-top: 1px solid #ccc;\n"
"}\n"
"\n"
".memTemplParams {\n"
"	color: #606060;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"/* @group Member Details */\n"
"\n"
"/* Styles for detailed member documentation */\n"
"\n"
".memtemplate {\n"
"	font-size: 80%;\n"
"	color: #606060;\n"
"	font-weight: normal;\n"
"	margin-left: 3px;\n"
"}\n"
"\n"
".memnav {\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	margin-right: 15px;\n"
"	padding: 2px;\n"
"}\n"
"\n"
".memitem {\n"
"	padding: 0;\n"
"}\n"
"\n"
".memname {\n"
"	white-space: nowrap;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
".memproto, .memdoc {\n"
"	border: 1px solid #84b0c7;	\n"
"}\n"
"\n"
".memproto {\n"
"	padding: 0;\n"
"	background-color: #d5e1e8;\n"
"	font-weight: bold;\n"
"	-webkit-border-top-left-radius: 8px;\n"
"	-webkit-border-top-right-radius: 8px;\n"
"	-moz-border-radius-topleft: 8px;\n"
"	-moz-border-radius-topright: 8px;\n"
"}\n"
"\n"
".memdoc {\n"
"	padding: 2px 5px;\n"
"	background-color: #eef3f5;\n"
"	border-top-width: 0;\n"
"	-webkit-border-bottom-left-radius: 8px;\n"
"	-webkit-border-bottom-right-radius: 8px;\n"
"	-moz-border-radius-bottomleft: 8px;\n"
"	-moz-border-radius-bottomright: 8px;\n"
"}\n"
"\n"
".memdoc p, .memdoc dl, .memdoc ul {\n"
"	margin: 6px 0;\n"
"}\n"
"\n"
".paramkey {\n"
"	text-align: right;\n"
"}\n"
"\n"
".paramtype {\n"
"	white-space: nowrap;\n"
"}\n"
"\n"
".paramname {\n"
"	color: #602020;\n"
"	white-space: nowrap;\n"
"}\n"
".paramname em {\n"
"	font-style: normal;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"/* @group Directory (tree) */\n"
"\n"
"/* for the tree view */\n"
"\n"
".ftvtree {\n"
"	font-family: sans-serif;\n"
"	margin: 0.5em;\n"
"}\n"
"\n"
"/* these are for tree view when used as main index */\n"
"\n"
".directory {\n"
"	font-size: 9pt;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
".directory h3 {\n"
"	margin: 0px;\n"
"	margin-top: 1em;\n"
"	font-size: 11pt;\n"
"}\n"
"\n"
"/*\n"
"The following two styles can be used to replace the root node title\n"
"with an image of your choice.  Simply uncomment the next two styles,\n"
"specify the name of your image and be sure to set 'height' to the\n"
"proper pixel height of your image.\n"
"*/\n"
"\n"
"/*\n"
".directory h3.swap {\n"
"	height: 61px;\n"
"	background-repeat: no-repeat;\n"
"	background-image: url(\"yourimage.gif\");\n"
"}\n"
".directory h3.swap span {\n"
"	display: none;\n"
"}\n"
"*/\n"
"\n"
".directory > h3 {\n"
"	margin-top: 0;\n"
"}\n"
"\n"
".directory p {\n"
"	margin: 0px;\n"
"	white-space: nowrap;\n"
"}\n"
"\n"
".directory div {\n"
"	display: none;\n"
"	margin: 0px;\n"
"}\n"
"\n"
".directory img {\n"
"	vertical-align: -30%;\n"
"}\n"
"\n"
"/* these are for tree view when not used as main index */\n"
"\n"
".directory-alt {\n"
"	font-size: 100%;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
".directory-alt h3 {\n"
"	margin: 0px;\n"
"	margin-top: 1em;\n"
"	font-size: 11pt;\n"
"}\n"
"\n"
".directory-alt > h3 {\n"
"	margin-top: 0;\n"
"}\n"
"\n"
".directory-alt p {\n"
"	margin: 0px;\n"
"	white-space: nowrap;\n"
"}\n"
"\n"
".directory-alt div {\n"
"	display: none;\n"
"	margin: 0px;\n"
"}\n"
"\n"
".directory-alt img {\n"
"	vertical-align: -30%;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"address {\n"
"	font-style: normal;\n"
"	color: #333;\n"
"}\n"

==> doxygen-1.5.8.src.tar.bz2: doxygen-1.5.8/src/doxygen_css.h <==
"body, table, div, p, dl {\n"
"	font-family: Lucida Grande, Verdana, Geneva, Arial, sans-serif;\n"
"	font-size: 12px;\n"
"}\n"
"\n"
"/* @group Heading Levels */\n"
"\n"
"h1 {\n"
"	text-align: center;\n"
"	font-size: 150%;\n"
"}\n"
"\n"
"h2 {\n"
"	font-size: 120%;\n"
"}\n"
"\n"
"h3 {\n"
"	font-size: 100%;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"caption {\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"div.qindex, div.navtab{\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	padding: 2px;\n"
"}\n"
"\n"
"div.qindex, div.navpath {\n"
"	width: 100%;\n"
"	line-height: 140%;\n"
"}\n"
"\n"
"div.navtab {\n"
"	margin-right: 15px;\n"
"}\n"
"\n"
"/* @group Link Styling */\n"
"\n"
"a {\n"
"	color: #153788;\n"
"	font-weight: normal;\n"
"	text-decoration: none;\n"
"}\n"
"\n"
".contents a:visited {\n"
"	color: #1b77c5;\n"
"}\n"
"\n"
"a:hover {\n"
"	text-decoration: underline;\n"
"}\n"
"\n"
"a.qindex {\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"a.qindexHL {\n"
"	font-weight: bold;\n"
"	background-color: #6666cc;\n"
"	color: #ffffff;\n"
"	border: 1px double #9295C2;\n"
"}\n"
"\n"
".contents a.qindexHL:visited {\n"
"        color: #ffffff;\n"
"}\n"
"\n"
"a.el {\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"a.elRef {\n"
"}\n"
"\n"
"a.code {\n"
"}\n"
"\n"
"a.codeRef {\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"dl.el {\n"
"	margin-left: -1cm;\n"
"}\n"
"\n"
".fragment {\n"
"	font-family: monospace, fixed;\n"
"	font-size: 105%;\n"
"}\n"
"\n"
"pre.fragment {\n"
"	border: 1px solid #CCCCCC;\n"
"	background-color: #f5f5f5;\n"
"	padding: 4px 6px;\n"
"	margin: 4px 8px 4px 2px;\n"
"}\n"
"\n"
"div.ah {\n"
"	background-color: black;\n"
"	font-weight: bold;\n"
"	color: #ffffff;\n"
"	margin-bottom: 3px;\n"
"	margin-top: 3px\n"
"}\n"
"\n"
"div.groupHeader {\n"
"	margin-left: 16px;\n"
"	margin-top: 12px;\n"
"	margin-bottom: 6px;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"div.groupText {\n"
"	margin-left: 16px;\n"
"	font-style: italic;\n"
"}\n"
"\n"
"body {\n"
"	background: white;\n"
"	color: black;\n"
"	margin-right: 20px;\n"
"	margin-left: 20px;\n"
"}\n"
"\n"
"td.indexkey {\n"
"	background-color: #e8eef2;\n"
"	font-weight: bold;\n"
"	border: 1px solid #CCCCCC;\n"
"	margin: 2px 0px 2px 0;\n"
"	padding: 2px 10px;\n"
"}\n"
"\n"
"td.indexvalue {\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #CCCCCC;\n"
"	padding: 2px 10px;\n"
"	margin: 2px 0px;\n"
"}\n"
"\n"
"tr.memlist {\n"
"	background-color: #f0f0f0;\n"
"}\n"
"\n"
"p.formulaDsp {\n"
"	text-align: center;\n"
"}\n"
"\n"
"img.formulaDsp {\n"
"	\n"
"}\n"
"\n"
"img.formulaInl {\n"
"	vertical-align: middle;\n"
"}\n"
"\n"
"/* @group Code Colorization */\n"
"\n"
"span.keyword {\n"
"	color: #008000\n"
"}\n"
"\n"
"span.keywordtype {\n"
"	color: #604020\n"
"}\n"
"\n"
"span.keywordflow {\n"
"	color: #e08000\n"
"}\n"
"\n"
"span.comment {\n"
"	color: #800000\n"
"}\n"
"\n"
"span.preprocessor {\n"
"	color: #806020\n"
"}\n"
"\n"
"span.stringliteral {\n"
"	color: #002080\n"
"}\n"
"\n"
"span.charliteral {\n"
"	color: #008080\n"
"}\n"
"\n"
"span.vhdldigit { \n"
"	color: #ff00ff \n"
"}\n"
"\n"
"span.vhdlchar { \n"
"	color: #000000 \n"
"}\n"
"\n"
"span.vhdlkeyword { \n"
"	color: #700070 \n"
"}\n"
"\n"
"span.vhdllogic { \n"
"	color: #ff0000 \n"
"}\n"
"\n"
"/* @end */\n"
"\n"
".search {\n"
"	color: #003399;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"form.search {\n"
"	margin-bottom: 0px;\n"
"	margin-top: 0px;\n"
"}\n"
"\n"
"input.search {\n"
"	font-size: 75%;\n"
"	color: #000080;\n"
"	font-weight: normal;\n"
"	background-color: #e8eef2;\n"
"}\n"
"\n"
"td.tiny {\n"
"	font-size: 75%;\n"
"}\n"
"\n"
".dirtab {\n"
"	padding: 4px;\n"
"	border-collapse: collapse;\n"
"	border: 1px solid #84b0c7;\n"
"}\n"
"\n"
"th.dirtab {\n"
"	background: #e8eef2;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
"hr {\n"
"	height: 0;\n"
"	border: none;\n"
"	border-top: 1px solid #666;\n"
"}\n"
"\n"
"/* @group Member Descriptions */\n"
"\n"
".mdescLeft, .mdescRight,\n"
".memItemLeft, .memItemRight,\n"
".memTemplItemLeft, .memTemplItemRight, .memTemplParams {\n"
"	background-color: #FAFAFA;\n"
"	border: none;\n"
"	margin: 4px;\n"
"	padding: 1px 0 0 8px;\n"
"}\n"
"\n"
".mdescLeft, .mdescRight {\n"
"	padding: 0px 8px 4px 8px;\n"
"	color: #555;\n"
"}\n"
"\n"
".memItemLeft, .memItemRight, .memTemplParams {\n"
"	border-top: 1px solid #ccc;\n"
"}\n"
"\n"
".memTemplParams {\n"
"	color: #606060;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"/* @group Member Details */\n"
"\n"
"/* Styles for detailed member documentation */\n"
"\n"
".memtemplate {\n"
"	font-size: 80%;\n"
"	color: #606060;\n"
"	font-weight: normal;\n"
"	margin-left: 3px;\n"
"}\n"
"\n"
".memnav {\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	margin-right: 15px;\n"
"	padding: 2px;\n"
"}\n"
"\n"
".memitem {\n"
"	padding: 0;\n"
"}\n"
"\n"
".memname {\n"
"	white-space: nowrap;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
".memproto, .memdoc {\n"
"	border: 1px solid #84b0c7;	\n"
"}\n"
"\n"
".memproto {\n"
"	padding: 0;\n"
"	background-color: #d5e1e8;\n"
"	font-weight: bold;\n"
"	-webkit-border-top-left-radius: 8px;\n"
"	-webkit-border-top-right-radius: 8px;\n"
"	-moz-border-radius-topleft: 8px;\n"
"	-moz-border-radius-topright: 8px;\n"
"}\n"
"\n"
".memdoc {\n"
"	padding: 2px 5px;\n"
"	background-color: #eef3f5;\n"
"	border-top-width: 0;\n"
"	-webkit-border-bottom-left-radius: 8px;\n"
"	-webkit-border-bottom-right-radius: 8px;\n"
"	-moz-border-radius-bottomleft: 8px;\n"
"	-moz-border-radius-bottomright: 8px;\n"
"}\n"
"\n"
".paramkey {\n"
"	text-align: right;\n"
"}\n"
"\n"
".paramtype {\n"
"	white-space: nowrap;\n"
"}\n"
"\n"
".paramname {\n"
"	color: #602020;\n"
"	white-space: nowrap;\n"
"}\n"
".paramname em {\n"
"	font-style: normal;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"/* @group Directory (tree) */\n"
"\n"
"/* for the tree view */\n"
"\n"
".ftvtree {\n"
"	font-family: sans-serif;\n"
"	margin: 0.5em;\n"
"}\n"
"\n"
"/* these are for tree view when used as main index */\n"
"\n"
".directory {\n"
"	font-size: 9pt;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
".directory h3 {\n"
"	margin: 0px;\n"
"	margin-top: 1em;\n"
"	font-size: 11pt;\n"
"}\n"
"\n"
"/*\n"
"The following two styles can be used to replace the root node title\n"
"with an image of your choice.  Simply uncomment the next two styles,\n"
"specify the name of your image and be sure to set 'height' to the\n"
"proper pixel height of your image.\n"
"*/\n"
"\n"
"/*\n"
".directory h3.swap {\n"
"	height: 61px;\n"
"	background-repeat: no-repeat;\n"
"	background-image: url(\"yourimage.gif\");\n"
"}\n"
".directory h3.swap span {\n"
"	display: none;\n"
"}\n"
"*/\n"
"\n"
".directory > h3 {\n"
"	margin-top: 0;\n"
"}\n"
"\n"
".directory p {\n"
"	margin: 0px;\n"
"	white-space: nowrap;\n"
"}\n"
"\n"
".directory div {\n"
"	display: none;\n"
"	margin: 0px;\n"
"}\n"
"\n"
".directory img {\n"
"	vertical-align: -30%;\n"
"}\n"
"\n"
"/* these are for tree view when not used as main index */\n"
"\n"
".directory-alt {\n"
"	font-size: 100%;\n"
"	font-weight: bold;\n"
"}\n"
"\n"
".directory-alt h3 {\n"
"	margin: 0px;\n"
"	margin-top: 1em;\n"
"	font-size: 11pt;\n"
"}\n"
"\n"
".directory-alt > h3 {\n"
"	margin-top: 0;\n"
"}\n"
"\n"
".directory-alt p {\n"
"	margin: 0px;\n"
"	white-space: nowrap;\n"
"}\n"
"\n"
".directory-alt div {\n"
"	display: none;\n"
"	margin: 0px;\n"
"}\n"
"\n"
".directory-alt img {\n"
"	vertical-align: -30%;\n"
"}\n"
"\n"
"/* @end */\n"
"\n"
"address {\n"
"	font-style: normal;\n"
"	color: #333;\n"
"}\n"
